@@ -16,4 +16,10 @@ LOGIN_PATH = "/accounts/login/"
 API_LOGGEDIN_NEXT_URL = "/user/api-logged-in/"
 STORY_VIEW_URL = "/story/view/{0}/"
 STORY_MANAGE_URL = "/story/manage/{0}/"
-DEFAULT_AUDIENCE = "https://api.presalytics.io/"
\ No newline at end of file
+DEFAULT_AUDIENCE = "https://api.presalytics.io/"
+DEFAULT_HOST_EVENTS = "https://api.presalytics.io/events"
+DEFAULT_HOST_STORY = "https://api.presalytics.io/story"
+DEFAULT_HOST_OOXML_AUTOMATION = "https://api.presalytics.io/ooxml-automation"
+DEFAULT_HOST_SITE = "https://presalytics.io"
+DEFAULT_HOST_WORKSPACE_API = "https://api.presalytics.io/workspace"
+DEFAULT_HOST_DOC_CONVERTER = "https://api.presalytics.io/doc-converter"
