@@ -15,6 +15,7 @@ if typing.TYPE_CHECKING:
 
 logger = logging.getLogger(__name__)
 
+
 def update_components(filename=None):
     autodiscover_paths = presalytics.COMPONENTS.autodiscover_paths
     dirname = os.path.dirname(filename)
@@ -25,14 +26,15 @@ def update_components(filename=None):
     if os.path.exists(abs_filedir) and abs_filedir not in autodiscover_paths:
         autodiscover_paths.append(abs_filedir)
     if len(autodiscover_paths) > len(presalytics.COMPONENTS.autodiscover_paths):
-        presalytics.COMPONENTS = presalytics.story.components.ComponentRegistry(autodiscover_paths=autodiscover_paths, 
-                                                                                reserved_names=presalytics.CONFIG.get("RESERVED_NAMES", []))
+        presalytics.COMPONENTS = presalytics.story.components.ComponentRegistry(autodiscover_paths=autodiscover_paths,
+                                                                                reserved_names=presalytics.settings.RESERVED_NAMES)
+
 
 def get_component(name, filename=None):
     inst: 'ComponentBase'
 
     if filename:
-        update_components(filename=filename)            
+        update_components(filename=filename)
     component_list = presalytics.COMPONENTS.find_instance(name)
     if len(component_list) == 0:
         message = "Could not find an instance with name '{0}' in the COMPONENTS registry".format(name)
@@ -47,6 +49,7 @@ def get_component(name, filename=None):
         message = "Error searching the COMPONENTS registry"
         presalytics.COMPONENTS.raise_error(message)
 
+
 def add_widget_instance(widget_name, outline, position=None, page_number=0, filename=None):
     inst: 'WidgetBase'
     outline: 'StoryOutline'
@@ -64,6 +67,7 @@ def add_widget_instance(widget_name, outline, position=None, page_number=0, file
 
     return outline
 
+
 def remove_widget_by_name(widget_name, outline, page_number=None, filename=None):
     inst: 'WidgetBase'
     outline: 'StoryOutline'
@@ -74,18 +78,17 @@ def remove_widget_by_name(widget_name, outline, page_number=None, filename=None)
     else:
         start = 0
         stop = len(outline.pages)
-    
+
     for p in range(start, stop):
         page = outline.pages[p]
         for w in range(0, len(page.widgets)):
             if page.widgets[w].name == widget_name:
                 page.widgets.pop(w)
-    
+
     return outline
 
 
-
-def create_from_instance(name, widget=False, page=False, filename=None) -> 'StoryOutline': #type: ignore
+def create_from_instance(name, widget=False, page=False, filename=None) -> 'StoryOutline':  # type: ignore
     """
     Creates a Story Outline from an instance name in `presalytics.COMPONENTS`
     """
@@ -93,15 +96,14 @@ def create_from_instance(name, widget=False, page=False, filename=None) -> 'Stor
 
     inst = get_component(name)
     if page:
-        outline = presalytics.lib.tools.component_tools.create_outline_from_page(inst) #type: ignore
+        outline = presalytics.lib.tools.component_tools.create_outline_from_page(inst)  # type: ignore
     elif widget:
-        outline = presalytics.lib.tools.component_tools.create_outline_from_widget(inst) #type: ignore
+        outline = presalytics.lib.tools.component_tools.create_outline_from_widget(inst)  # type: ignore
     else:
         raise presalytics.lib.exceptions.InvalidArgumentException("Either the 'widget' or 'page' paramters must be true.")
     return outline
 
 
-
 def push_outline(outline, username=None, password=None) -> 'StoryOutline':
     """
     Updates an outline in the Presalytics API Story service
@@ -131,11 +133,11 @@ def pull_outline(story_id, username=None, password=None) -> 'StoryOutline':
 
 def delete_all_stories(username=None, password=None):
     """
-    WARNING!!! 
-    
+    WARNING!!!
+
     Delete all stories owned by this user
 
-    BE CAREFUL!!!    
+    BE CAREFUL!!!
     """
     client = presalytics.client.api.Client(username=username, password=password)
     stories = client.story.story_get()
@@ -151,10 +153,11 @@ def delete_by_id(story_id, username=None, password=None):
     client = presalytics.client.api.Client(username=username, password=password)
     client.story.story_id_delete(story_id)
 
+
 def share_story(story_id,
-                emails=None, 
-                user_ids=None, 
-                username=None, 
+                emails=None,
+                user_ids=None,
+                username=None,
                 password=None,
                 collaborator_type="viewer"):
     """
@@ -180,6 +183,7 @@ def share_story(story_id,
             }
             client.story.story_id_collaborators_post(story_id, body)
 
+
 def get_story(story_id):
     """
     returns Story metadata from the story API
@@ -187,6 +191,7 @@ def get_story(story_id):
     client = presalytics.client.api.Client()
     return client.story.story_id_get(story_id, include_relationships=True)
 
+
 def create_config_file(username, password=None, set_dict={}, overwrite=False):
     config_file = os.path.join(os.getcwd(), "config.py")
     if os.path.exists(config_file):
@@ -204,6 +209,7 @@ def create_config_file(username, password=None, set_dict={}, overwrite=False):
     with open(config_file, 'w') as f:
         f.write(content)
 
+
 def create_cron_target():
     if sys.platform.startswith("linux"):
         cron_command = "* * * * * cd {0} && {1} -m presalytics push".format(os.getcwd(), sys.executable)
@@ -219,6 +225,7 @@ def create_cron_target():
         logger.error("Unknown operating system.")
         raise ValueError
 
+
 def apply_json_patch(outline, patch):
     """
     Allows users to apply json patches to thier Story Outlines.
@@ -249,13 +256,14 @@ def apply_json_patch(outline, patch):
     new_outline = presalytics.story.outline.StoryOutline.deserialize(new_dict)
     return new_outline
 
+
 def update_outline(outline, filename=None, message=None):
     """
     Updates the the outline from active instances in the workspace
     """
     if not message:
         message = "Automated update via presalytics.lib.tools.workflows.update_outline()"
-    
+
     update_components(filename=filename)
 
     for p in range(0, len(outline.pages)):
@@ -265,16 +273,15 @@ def update_outline(outline, filename=None, message=None):
         page_inst = presalytics.COMPONENTS.get_instance(page_key)
         if page_inst:
             outline.pages[p] = page_inst.serialize()
-        
+
         for w in range(0, len(page.widgets)):
             widget = outline.pages[p].widgets[w]
 
             widget_key = "widget.{}.{}".format(widget.kind, widget.name)
             widget_inst = presalytics.COMPONENTS.get_instance(widget_key)
             if widget_inst:
-                outline.pages[p].widgets[w] = widget_inst.serialize() 
+                outline.pages[p].widgets[w] = widget_inst.serialize()
 
-    
     for t in range(0, len(outline.themes)):
         theme = outline.themes[t]
 
@@ -282,13 +289,6 @@ def update_outline(outline, filename=None, message=None):
         theme_inst = presalytics.COMPONENTS.get_instance(theme_key)
         if theme_inst:
             outline.themes[t] = theme_inst.serialize()
-    
+
     outline.info.revision_notes = message
     return outline
-
-
-    
-    
-
-
-    
\ No newline at end of file
