@@ -1,7 +1,6 @@
 
 import typing
 import base64
-import uuid
 import logging
 import jinja2
 import json
@@ -35,13 +34,13 @@ class ChartWidget(presalytics.story.components.WidgetBase):
 
     chart_data: dict
         Data that will be loaded into the `c3.generate()` method.  Please go
-        to [c3js.org](https://c3js.org/gettingstarted.html) for more information 
+        to [c3js.org](https://c3js.org/gettingstarted.html) for more information
         on how to configure this object.
 
     css64 : str. optional
         A base64-encoded string of the css styles to apply to the d3 document.  Used for server-to-server
         transport over https.
-    
+
     css_filename: str, optional
         A css file containing styles that will be applied to d3
 
@@ -50,7 +49,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
     """
     __component_kind__ = 'chart'
 
-    def __init__(self, 
+    def __init__(self,
                  name: str,
                  chart_data: typing.Dict,
                  css64: str = None,
@@ -70,7 +69,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
         """
         data64 = None
         if filename:
-            search_paths = list(set(presalytics.autodiscover_paths))
+            search_paths = list(set(presalytics.settings.AUTODISCOVER_PATHS))  # type: ignore
             if os.getcwd() not in search_paths:
                 search_paths.append(os.getcwd())
             for path in search_paths:
@@ -78,7 +77,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
                 if os.path.exists(fpath):
                     with open(fpath, 'rb') as f:
                         data = f.read()
-                        data64 = base64.b64encode(data).decode('utf-8')  #type: ignore
+                        data64 = base64.b64encode(data).decode('utf-8')  # type: ignore
                     break
             if not data64:
                 logger.debug("File {0} could not be found".format(filename))
@@ -88,7 +87,6 @@ class ChartWidget(presalytics.story.components.WidgetBase):
         if 'bindto' not in self.chart_data.keys():
             self.chart_data['bindto'] = '#chart'
 
-
     def to_html(self, data=None, **kwargs) -> str:
         """
         Renders the sandboxed iframe with will contain the d3 script widget
@@ -96,7 +94,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
         html = self.create_container()
         return html
 
-    def create_container(self, **kwargs):
+    def create_container(self, **kwargs) -> str:
         """
         Wraps the D3 objects in an endpoint at the story API load via a sandboxed `<iframe>` that
         will be rendered
@@ -116,12 +114,13 @@ class ChartWidget(presalytics.story.components.WidgetBase):
             'sandbox': 'allow-scripts allow-same-origin'
         })
         empty_parent_div.append(frame)
-        return lxml.html.tostring(empty_parent_div).decode('utf-8')
+        return lxml.html.tostring(empty_parent_div).decode('utf-8')  # type: ignore
 
     @classmethod
     def deserialize(cls, outline, **kwargs):
         chart_data = outline.data.get("chart_data")
         return cls(outline.name,
+                   id=outline.id,
                    chart_data=chart_data,
                    **kwargs)
 
@@ -132,6 +131,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
         return presalytics.story.outline.Widget(
             name=self.name,
             kind=self.__component_kind__,
+            id=self.id,
             data=data,
         )
 
@@ -162,12 +162,9 @@ class ChartWidget(presalytics.story.components.WidgetBase):
     }
     """
 
-
-
     def create_subdocument(self, **kwargs):
         return self.standalone_html()
 
-
     def standalone_html(self) -> str:
         """
         Returns string with an html document containing that d3 widget
@@ -190,7 +187,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
                 <div id="chart" class="chart-container"></div>
                 <script type="text/javascript">
 
-                    document.addEventListener("DOMContentLoaded", (event) => { 
+                    document.addEventListener("DOMContentLoaded", (event) => {
                         var data = JSON.parse('{{data|safe}}');
 
                         var aspectRatio = data.aspectRatio || 0.5625; // 16:9 AR
@@ -207,7 +204,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
                                 chart.resize({height: newHeight});
                                 chart.internal.selectChart.style('max-height', 'none');
                             }, 500);
-                            
+
                         }
 
                         const observer = new ResizeObserver(c3Resize);
@@ -220,7 +217,7 @@ class ChartWidget(presalytics.story.components.WidgetBase):
             </body>
         </html>""")
         data = json.dumps(self.chart_data)  # dont use hyphens in data keys
-        extra_css = base64.b64decode(self.css64).decode('utf-8') if self.css64 else ChartWidget.DEFAULT_CSS  #type: ignore  
+        extra_css = base64.b64decode(self.css64).decode('utf-8') if self.css64 else ChartWidget.DEFAULT_CSS  # type: ignore
         context = {
             "c3_styles_url": presalytics.lib.plugins.external.ApprovedExternalLinks().attr_dict.flatten().get('c3'),
             "c3_script_url": presalytics.lib.plugins.external.ApprovedExternalScripts().attr_dict.flatten().get('c3'),
@@ -229,4 +226,4 @@ class ChartWidget(presalytics.story.components.WidgetBase):
             "data": data,
             "css": extra_css
         }
-        return SIMPLE_HTML.render(**context)
\ No newline at end of file
+        return SIMPLE_HTML.render(**context)
