@@ -7,7 +7,6 @@ import lxml.etree
 import abc
 import re
 import requests
-import collections
 import presalytics
 import presalytics.lib.registry
 import presalytics.lib.exceptions
@@ -21,8 +20,8 @@ class XmlTransformBase(abc.ABC):
     """
     Base class for writing Open Office Xml tranform functions to be implemented
     by `presalytics.lib.widgets.ooxml_editors.OoxmlEditorWidget`
-    
-    *For more information about Open Office Xml Schema that underlies 
+
+    *For more information about Open Office Xml Schema that underlies
     .pptx and .xlsx files, see http://officeopenxml.com/
 
     *For more information on how to lxml to write transforms, consult https://lxml.de/
@@ -45,11 +44,10 @@ class XmlTransformBase(abc.ABC):
         variables. Must be overridden in subclasses.
         """
         pass
-    
 
     def execute(self, lxml_element: lxml.etree.Element):
         """
-        Called by widget classes (e.g., `presalytics.lib.widgets.ooxml_editors.OoxmlEditorWidget`) to 
+        Called by widget classes (e.g., `presalytics.lib.widgets.ooxml_editors.OoxmlEditorWidget`) to
         perform the updates prescribed in the `transform_function`
         """
         return self.transform_function(lxml_element, self.function_params)
@@ -58,7 +56,7 @@ class XmlTransformBase(abc.ABC):
 class ChangeShapeColor(XmlTransformBase):
     """
     Changes the color of a set of [Open Office Xml Shapes](http://officeopenxml.com/drwShape.php)
-    
+
     Function Parameters Dictionary
     ----------
     hex_color : str
@@ -67,7 +65,7 @@ class ChangeShapeColor(XmlTransformBase):
 
     object_name : str, optional
         The object tree name of the target shape.  If not supplied, all descendent shapes will
-        have their color changed.      
+        have their color changed.
     """
     __xml_transform_name__ = "ChangeShapeColor"
 
@@ -110,7 +108,7 @@ class ChangeShapeColor(XmlTransformBase):
         params : dict
             See the `Function Parameters Dictionary` for required entries
         """
-        
+
         if re.match('{.*}sp', lxml_element.tag):
             shapes = [lxml_element]
         else:
@@ -132,9 +130,10 @@ class ChangeShapeColor(XmlTransformBase):
                 shape = ChangeShapeColor.replace_color_on_target_shape(shape, color)
         return lxml_element
 
+
 class TextReplace(XmlTransformBase):
     """
-    Replaces text in a template built into an Office Office Xml object that has 
+    Replaces text in a template built into an Office Office Xml object that has
     been uploaded to the Presalytics Ooxml Automation service.  Text to be should
     be in the format of a "template tag", which is a string enclosed in handlebars
     as such: '{{template_tag}}'
@@ -145,19 +144,20 @@ class TextReplace(XmlTransformBase):
     replace_map: dict
         A dictionary that maps template tags to the new strings that will replace the
         tags in the rendered widget.  The the dictionary keys should not be enclosed in handlebars.
-    
+
     object_name: str, optional
         The name of a sub object will be the target of this function.  If not includes, this will
         default to the parent object.  Allows different replace map to be applied to multiple elements in
-        a widget    
+        a widget
 
     """
     __xml_transform_name__ = "TextReplace"
 
     class TextElementInfo(object):
         """
-        Holds metadata for a list of `<t>` tags from an Office Open Xml document. 
+        Holds metadata for a list of `<t>` tags from an Office Open Xml document.
         """
+
         def __init__(self, element: lxml.etree.Element, start_position: int):
             self.element = element
             self.text = "" if not element.text else element.text
@@ -179,7 +179,7 @@ class TextReplace(XmlTransformBase):
                 self._list.append(text_element_info)
             else:
                 raise presalytics.lib.exceptions.InvalidArgumentException(message="Argument must be an instance of class 'TextElementInfo'")
-        
+
         def set_text(self, index, new_string):
             self._list[index].text = new_string
             self._list[index].element.text = new_string
@@ -195,7 +195,7 @@ class TextReplace(XmlTransformBase):
 
         def get_position(self, match_strings):
             for potential_match in match_strings:
-                i = self.get_plaintext_string().find(potential_match) 
+                i = self.get_plaintext_string().find(potential_match)
                 if i >= 0:
                     break
             return i, potential_match
@@ -205,13 +205,13 @@ class TextReplace(XmlTransformBase):
                 if item.start_position <= position and item.end_position >= position:
                     return self.get_index(item)
             raise presalytics.lib.exceptions.InvalidArgumentException(message="Position {} out of range".format(position))
-        
+
         def get_index(self, text_element_info: 'TextReplace.TextElementInfo'):
             for i in range(len(self._list)):
                 if self._list[i] == text_element_info:
                     return i
             raise presalytics.lib.exceptions.InvalidArgumentException(message="Supplied argument on in self._list")
-        
+
         def set_text_to_empty_string(self, index):
             self._list[index].text = ""
             self._list[index].element.text = ""
@@ -235,20 +235,18 @@ class TextReplace(XmlTransformBase):
 
         def reset(self):
             for i in range(0, len(self._list)):
-                start_position = 0 if i == 0 else self._list[i-1].end_position + 1
+                start_position = 0 if i == 0 else self._list[i - 1].end_position + 1
                 self._list[i] = TextReplace.TextElementInfo(self._list[i].element, start_position)
 
-
-            
     def replace_handlebars(self, info_list, params):
         """
-        Method that finds template tags and replaces them 
+        Method that finds template tags and replaces them
 
         TODO: Upgrade to Liquid Syntax (or similar)
         """
         for key, val in params.items():
             match_keys = ["{{" + key + "}}", "{{ " + key + " }}"]
-            match_start_position, match_key =  info_list.get_position(match_keys)
+            match_start_position, match_key = info_list.get_position(match_keys)
             if match_start_position > -1:
                 match_end_position = match_start_position + len(match_key) - 1
                 match_start_index = info_list.get_list_index_of_position(match_start_position)
@@ -261,14 +259,13 @@ class TextReplace(XmlTransformBase):
                 info_list.reset()
                 self.replace_handlebars(info_list, params)
 
-
     def transform_function(self, lxml_element, params):
         """
         Replaces template tags located {{inside_handlebars}} that match keys in the
-        `params` dict with values from the `params` dict. 
+        `params` dict with values from the `params` dict.
 
         This method searches for match for plain text strings, so that if template
-        tags are split across xml `<t>` elements, they are still identified and replaced. 
+        tags are split across xml `<t>` elements, they are still identified and replaced.
 
         Parameters
         -----------
@@ -287,7 +284,7 @@ class TextReplace(XmlTransformBase):
                 if ele.get("name", None) == target_object_name:
                     target_object = ele.getparent().getparent()
                     break
-                
+
         text_list = target_object.findall('.//{*}t')
         info_list = TextReplace.TextList()
         position = 0
@@ -305,8 +302,9 @@ class XmlTransformRegistry(presalytics.lib.registry.RegistryBase):
     and `presalytics.lib.widgets.ooxml_editors.OoxmlEditorWidget` so XmlTransformBase subclasses
     can be deserialized at run-time without a loaded instance in `locals()`.
     """
+
     def __init__(self):
-        include_paths = presalytics.COMPONENTS.autodiscover_paths # todo: Change this line -does not exist at timport time.
+        include_paths = presalytics.COMPONENTS.autodiscover_paths  # todo: Change this line -does not exist at timport time.
         reserved_names = presalytics.COMPONENTS.reserved_names
         super(XmlTransformRegistry, self).__init__(autodiscover_paths=include_paths, reserved_names=reserved_names)
 
@@ -316,17 +314,21 @@ class XmlTransformRegistry(presalytics.lib.registry.RegistryBase):
     def get_type(self, klass):
         return getattr(klass, "__xml_transform_kind__", None)
 
+    def get_settings_object(self):
+        return presalytics.settings.XML_TRANSFORMS
+
 
 XML_TRANSFORM_REGISTRY = None
 """
-Static instance of `presalytics.lib.widgets.ooxml_editors.XmlTransformRegistry`. 
+Static instance of `presalytics.lib.widgets.ooxml_editors.XmlTransformRegistry`.
 
-Should not be used directly by consuming classes. Only initialized if a consuming 
+Should not be used directly by consuming classes. Only initialized if a consuming
 class or method calls the `presalytics.lib.widgets.ooxml_editors.get_transform_registry`.  This is done
-for performance reasons since there's no need to build this registry at import-time if its never 
+for performance reasons since there's no need to build this registry at import-time if its never
 used in a workspace.
 """
 
+
 def get_transform_registry():
     """
     Initalizes and retreives `presalytics.lib.widgets.ooxml_editors.XML_TRANSFORM_REGISTRY`
@@ -337,37 +339,36 @@ def get_transform_registry():
     return XML_TRANSFORM_REGISTRY
 
 
-
 class MultiXmlTransform(XmlTransformBase):
     """
     This class allow users to run mutiple transforms on multiple targets in a single widget.  `MultiXmlTransform`
     wraps multiple subclasses of `presalytics.lib.widgets.ooxml_editors.XmlTransformBase`, creates instances of
     them, and feeds them into an `presalytics.lib.widgets.ooxml_editors.OoxmlEditorWidget` instance.  To do this,
-    the `presalytics.lib.widgets.ooxml_editors.XmlTransformBase` subclasses must be loaded into the 
+    the `presalytics.lib.widgets.ooxml_editors.XmlTransformBase` subclasses must be loaded into the
     `presalytics.lib.widgets.ooxml_editors.XML_TRANSFORM_REGISTRY` when called.
 
-    The function parameters for the 
+    The function parameters for the
 
     Parameters
     ----------
     fail_quietly: bool, optional
         Defaults to false.  Indicates whether an exception should be raised when a subclass specified
         in the function parameters cannot not be found in the `presalytics.lib.widgets.ooxml_editors.XML_TRANSFORM_REGISTRY`
-        instance. 
-        
+        instance.
+
 
     Function Parameters Dictionary
     ----------
     transforms_list: list of dict
-        A list of dictionaries, with each item in the list consiting of a dictionary of two entries.  
+        A list of dictionaries, with each item in the list consiting of a dictionary of two entries.
         The entries are as follows:
-         
+
          * name: [str]
             The name of the the subclass of `presalytics.lib.widgets.ooxml_editors.XmlTransformBase` that
             will be that will be initialized
-         
+
          * function_params: [dict]
-            The `params` that will be the loaded into the instance's `transform_function` 
+            The `params` that will be the loaded into the instance's `transform_function`
     """
     transform_instances: typing.List[XmlTransformBase]
 
@@ -379,7 +380,7 @@ class MultiXmlTransform(XmlTransformBase):
         self.fail_quietly = fail_quietly
         self.transform_instances = []
         self.transform_registry = get_transform_registry()
-        for _transform in transforms_list: #type: ignore
+        for _transform in transforms_list:  # type: ignore
             key = "XmlTransform." + _transform["name"]
             transform_class = self.transform_registry.get(key)
             if not transform_class:
@@ -387,7 +388,7 @@ class MultiXmlTransform(XmlTransformBase):
                 if self.fail_quietly:
                     logging.info(message)
                 else:
-                    raise self.transform_registry.raise_error(message) #noqa
+                    raise self.transform_registry.raise_error(message)  # noqa
             else:
                 inst = transform_class(_transform["function_params"])
                 self.transform_instances.append(inst)
@@ -395,19 +396,19 @@ class MultiXmlTransform(XmlTransformBase):
     def transform_function(self, lxml_element, params):
         for inst in self.transform_instances:
             lxml_element = inst.execute(lxml_element)
-        return lxml_element    
+        return lxml_element
 
 
 class OoxmlEditorWidget(presalytics.lib.widgets.ooxml.OoxmlWidgetBase):
     """
-    Edits a `widget` from a Presentation or Spreadsheet document and renders 
+    Edits a `widget` from a Presentation or Spreadsheet document and renders
     the edited widget.
 
     This class interacts with the Presalytics API to extract SVG objects from
     Presentation and spreadsheet documents, from Presaltytics Ooxml Automation
     service objects that have already been loaded into the API.  This class requires
-    that users supply `transform_function` by subclassing 
-    `presalytics.lib.widgets.ooxml_editors.XmlTransformBase`, and an optional set of 
+    that users supply `transform_function` by subclassing
+    `presalytics.lib.widgets.ooxml_editors.XmlTransformBase`, and an optional set of
     parameters to act as variables in the transform function.
 
     Parameters
@@ -417,15 +418,15 @@ class OoxmlEditorWidget(presalytics.lib.widgets.ooxml.OoxmlWidgetBase):
         the object to be rendered
 
     name : str
-        The widget name.  If not provided, attribute will be set as the `object_name` 
+        The widget name.  If not provided, attribute will be set as the `object_name`
         or `filename`
 
     story_id : str
-        The the id of the story in the Presalytics API Story service.  If not provided, 
-        a new story will be created.  Do not supply if this object has not yet been created. 
-    
+        The the id of the story in the Presalytics API Story service.  If not provided,
+        a new story will be created.  Do not supply if this object has not yet been created.
+
     object_ooxml_id : str
-        The identifier of the Ooxml Automation service object bound the Story. Do not supply if this 
+        The identifier of the Ooxml Automation service object bound the Story. Do not supply if this
         object has not yet been created.
 
     endpoint_map : presalytics.lib.widgets.ooxml.OoxmlEndpointMap
@@ -438,8 +439,8 @@ class OoxmlEditorWidget(presalytics.lib.widgets.ooxml.OoxmlWidgetBase):
 
     transform_params : dict, optional
         A dictionary of parameters that will be passed to the `transform_class`'s `transform_function`
-        as variables to modify the underlying OpenOfficeXml 
-    
+        as variables to modify the underlying OpenOfficeXml
+
     """
     transform: XmlTransformBase
 
